==> haskell-th-lift-instances-0.1.18-80-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-lift-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-lift-instances
version:              0.1.18
visibility:           public
id:                   th-lift-instances-0.1.18-D8xbmf4aEv7KKE6pjHfR6K
key:                  th-lift-instances-0.1.18-D8xbmf4aEv7KKE6pjHfR6K
license:              BSD-3-Clause
copyright:            Copyright (C) 2013-2020 Benno Fünfstück
maintainer:           Benno Fünfstück <benno.fuenfstueck@gmail.com>
author:               Benno Fünfstück
stability:            experimental
homepage:             http://github.com/bennofs/th-lift-instances/
synopsis:             Lift instances for template-haskell for common data types.
description:
    Most data types in the haskell platform do not have Lift instances.
    This package provides orphan instances for containers, text, bytestring and vector.
    It also provides compat instances for older versions of @template-haskell@

    Note that <https://hackage.haskell.org/package/th-lift th-lift> package provides
    Template Haskell based derivation of @Lift@ instances (when you cannot use @DeriveLift@ extension),
    and <https://hackage.haskell.org/package/th-orphans th-orphans> package provides instances for TH datatypes.

category:             Template Haskell
abi:                  ab228bf9782fbbc6c1318c0b0debf55c
exposed:              True
exposed-modules:      Instances.TH.Lift
import-dirs:          /usr/lib/ghc-9.0.1/site-local/th-lift-instances-0.1.18
library-dirs:         /usr/lib/ghc-9.0.1/site-local/th-lift-instances-0.1.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/th-lift-instances-0.1.18
hs-libraries:         HSth-lift-instances-0.1.18-D8xbmf4aEv7KKE6pjHfR6K
depends:
    base-4.15.0.0 bytestring-0.10.12.1 containers-0.6.4.1
    template-haskell-2.17.0.0 text-1.2.4.1
    th-lift-0.8.2-F0VVOrB5SZgFNS1AEtieR9 transformers-0.5.6.2
    vector-0.12.3.1-HMAplmdcuCN6dtD8e6QGwL

haddock-interfaces:
    /usr/share/doc/haskell-th-lift-instances/html/th-lift-instances.haddock

haddock-html:         /usr/share/doc/haskell-th-lift-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-lift-instances-0.1.19-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-lift-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-lift-instances
version:              0.1.19
visibility:           public
id:                   th-lift-instances-0.1.19-2wg216phHavDGk4KuBqXQq
key:                  th-lift-instances-0.1.19-2wg216phHavDGk4KuBqXQq
license:              BSD-3-Clause
copyright:            Copyright (C) 2013-2020 Benno Fünfstück
maintainer:           Benno Fünfstück <benno.fuenfstueck@gmail.com>
author:               Benno Fünfstück
stability:            experimental
homepage:             http://github.com/bennofs/th-lift-instances/
synopsis:             Lift instances for template-haskell for common data types.
description:
    Most data types in the haskell platform do not have Lift instances.
    This package provides orphan instances for containers, text, bytestring and vector.
    It also provides compat instances for older versions of @template-haskell@

    Note that <https://hackage.haskell.org/package/th-lift th-lift> package provides
    Template Haskell based derivation of @Lift@ instances (when you cannot use @DeriveLift@ extension),
    and <https://hackage.haskell.org/package/th-orphans th-orphans> package provides instances for TH datatypes.

category:             Template Haskell
abi:                  4a340ccc2210f9374bc7d422a54509b7
exposed:              True
exposed-modules:      Instances.TH.Lift
import-dirs:          /usr/lib/ghc-9.0.1/site-local/th-lift-instances-0.1.19
library-dirs:         /usr/lib/ghc-9.0.1/site-local/th-lift-instances-0.1.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/th-lift-instances-0.1.19
hs-libraries:         HSth-lift-instances-0.1.19-2wg216phHavDGk4KuBqXQq
depends:
    base-4.15.0.0 bytestring-0.10.12.1 containers-0.6.4.1
    template-haskell-2.17.0.0 text-1.2.4.1
    th-lift-0.8.2-F0VVOrB5SZgFNS1AEtieR9 transformers-0.5.6.2
    vector-0.12.3.1-BYdg1PRFj4WB38iHU29MVy

haddock-interfaces:
    /usr/share/doc/haskell-th-lift-instances/html/th-lift-instances.haddock

haddock-html:         /usr/share/doc/haskell-th-lift-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
